/******************************************************************************/
/*                                                                            */
/* Name:   UNINSTALL.REX - uninstall the Information Center                   */
/* Author: David Page                                                         */
/* Date:   23rd May 2000                                                      */
/* Function:                                                                  */
/*         This REXX command uninstalls the Information Center.               */
/*                                                                            */
/*         Note that this command is modified during the installation         */
/*         process to add the appropriate invocations of the routine          */
/*         DeleteIndex following the comment "Remove any NetQuestion          */
/*         indexes".                                                          */
/*                                                                            */
/* Copyright statement */
/* (C) Copyright IBM Corporation 2001, 2002.  All Rights Reserved. */
/* Notice to U.S. Government Users - Materials Related to Restricted Rights. */
/*                                                                            */
/******************************************************************************/

/* Find out where we are                                                      */
Parse source . . command
sourceDirectory = truncate(command,length(filespec('name',command)))
If right(sourceDirectory,1)='\'
  then sourceDirectory = left(sourceDirectory,length(sourceDirectory)-1)

imninst = ''

/* Remove any NetQuestion indexes                                             */

/* Remove the root directory and all subdirectories                           */
Say 'Clearing the contents of directory' sourceDirectory '...'
Call ClearDirectory sourceDirectory
If sourceDirectory<>directory('.')
  then do
    say 'Removing directory' sourceDirectory '...'
    'RMDIR' sourceDirectory
  end

/* Clear the NetQuestion directory, if possible                               */
If imninst<>''
  then do
    say 'Removing directory' imninst '...'
    call RemoveDirectory imninst
  end

Say 'Removal of the Information Center is complete'

return

/******************************************************************************/
/*                 Required class definitions and routines                    */
/******************************************************************************/

  /****************************************************************************/
  /* Delete a NetQuestion index                                               */
  /****************************************************************************/
  ::routine DeleteIndex public
    Use arg indexName
    trash = queueCommand('imndomap -d' indexName)
    trash = queueCommand('imnixdel' indexName)
    return

  /****************************************************************************/
  /* Remove a directory and all its contents                                  */
  /****************************************************************************/
  ::routine RemoveDirectory public
    Use arg directoryName
    rc = ClearDirectory(directoryName)
    rc = SysRmDir(directoryName)
    return 0
    
  /****************************************************************************/
  /* Remove all the contents of a directory and its subdirectories            */
  /****************************************************************************/
  ::routine ClearDirectory public
    Use arg directoryName
    If right(directoryName,1)<>'\'
      then directoryName = directoryName'\'
    rc = SysFileTree(directoryName'*','dir','DO')
    do d=1 to dir.0
      rc = RemoveDirectory(dir.d)
    end
    rc = EraseAll(directoryName)
    return 0
    
  /****************************************************************************/
  /* Erase all the files in a directory                                       */
  /****************************************************************************/
  ::routine EraseAll public
    Use arg directoryName
    If right(directoryName,1)<>'\'
      then directoryName = directoryName'\'
    'ATTRIB -r *'
    rc = SysFileTree(directoryName'*','file','FO')
    do f=1 to file.0
      rc = SysFileDelete(file.f)
    end
    return 0
    
  /****************************************************************************/
  /*  Execute a command and return the input buffer                           */
  /****************************************************************************/
  ::routine queueCommand public
    use arg command
    /* Create a new buffer                                                    */
    newQueue = rxqueue('create')
    oldQueue = rxqueue('set', newQueue)
    /* Issue the command and read the input buffer                            */
    command '| RXqueue' newQueue
    inputBuffer = getQueue()
    /* Delete the buffer and restore the original buffer                      */
    call rxqueue 'Delete', newQueue
    call rxqueue 'Set', oldQueue
    /* Return the contents of the buffer                                      */
    return inputBuffer

  /****************************************************************************/
  /*  Concatenate the lines that are stacked in the input buffer              */
  /****************************************************************************/
  ::routine getQueue public
    queueData = ''
    do queued()
      parse pull line
      queueData = queueData || line || '0D0A'x
    end
    return queueData

  /****************************************************************************/
  /*  Truncate a string                                                       */
  /****************************************************************************/
  ::routine truncate public
    use arg string, length
    return left(string,length(string)-length)
    
/******************************************************************************/
/*  End of file                                                               */
/******************************************************************************/

